@@ -19,6 +19,7 @@ def collmex_login():
     b.getControl('Anmelden').click()
     return b
 
+
 def cleanup_collmex():
     # Prepare a clean environment in our Collmex testing.
     b = collmex_login()
@@ -44,7 +45,7 @@ def create_projects():
     # Projekt anlegen
     b.getLink('Verkauf').click()
     b.getLink(url=',pjcr').click()
-    assert b.title == 'Projekt anlegen'
+    assert b.title.startswith('Projekt anlegen')
 
     b.getControl('Projekt anlegen').click()
     b.getControl('Bezeichnung').value = 'Testprojekt'
